==> fastyle_dart-0.24.1.tar.gz: lib/ui/themes/light/light_themes.dart <==
import 'package:fastyle_dart/fastyle_dart.dart';
import 'package:flutter/cupertino.dart';

final kLightBlueFastTheme = FastThemeFactory.buildLightThemeWithColors(
  primaryColor: kFastLightBlueColor,
  primaryColorDark: CupertinoColors.systemBlue.highContrastColor,
  secondaryColor: kFastLightTealColor,
  tertiaryColor: kFastLightIndigoColor,
);

final kLightIndigoFastTheme = FastThemeFactory.buildLightThemeWithColors(
  primaryColor: kFastLightIndigoColor,
  primaryColorDark: CupertinoColors.systemIndigo.highContrastColor,
  secondaryColor: kFastLightPurpleColor,
  tertiaryColor: kFastLightTealColor,
);

final kLightPinkFastTheme = FastThemeFactory.buildLightThemeWithColors(
  primaryColor: kFastLightPinkColor,
  primaryColorDark: CupertinoColors.systemPink.highContrastColor,
  secondaryColor: kFastLightPurpleColor,
  tertiaryColor: kFastLightTealColor,
);

final kLightPurpleFastTheme = FastThemeFactory.buildLightThemeWithColors(
  primaryColor: kFastLightPurpleColor,
  primaryColorDark: CupertinoColors.systemPurple.highContrastColor,
  secondaryColor: kFastLightIndigoColor,
  tertiaryColor: kFastLightTealColor,
);

final kLightTealFastTheme = FastThemeFactory.buildLightThemeWithColors(
  primaryColor: kFastLightTealColor,
  primaryColorDark: CupertinoColors.systemTeal.highContrastColor,
  secondaryColor: kFastLightPurpleColor,
  tertiaryColor: kFastLightBlueColor,
);

final kLightYellowFastTheme = FastThemeFactory.buildLightThemeWithColors(
  primaryColor: kFastLightYellowColor,
  primaryColorDark: CupertinoColors.systemYellow.highContrastColor,
  secondaryColor: kFastLightIndigoColor,
  tertiaryColor: kFastLightTealColor,
);

final kLightOrangeFastTheme = FastThemeFactory.buildLightThemeWithColors(
  primaryColor: kFastLightOrangeColor,
  primaryColorDark: CupertinoColors.systemOrange.highContrastColor,
  secondaryColor: kFastLightIndigoColor,
  tertiaryColor: kFastLightTealColor,
);

==> fastyle_dart-0.30.2.tar.gz: lib/ui/themes/light/light_themes.dart <==
import 'package:fastyle_dart/fastyle_dart.dart';

final kLightBlueFastTheme = FastThemeFactory.buildLightThemeWithColors(
  primaryColor: kFastLightBlueColor,
  primaryColorDark: kFastLightBluePaletteColors.dark,
  secondaryColor: kFastLightTealColor,
  tertiaryColor: kFastLightIndigoColor,
);

final kLightIndigoFastTheme = FastThemeFactory.buildLightThemeWithColors(
  primaryColor: kFastLightIndigoColor,
  primaryColorDark: kFastLightIndigoPaletteColors.dark,
  secondaryColor: kFastLightPurpleColor,
  tertiaryColor: kFastLightTealColor,
);

final kLightPinkFastTheme = FastThemeFactory.buildLightThemeWithColors(
  primaryColor: kFastLightPinkColor,
  primaryColorDark: kFastLightPinkPaletteColors.dark,
  secondaryColor: kFastLightPurpleColor,
  tertiaryColor: kFastLightTealColor,
);

final kLightPurpleFastTheme = FastThemeFactory.buildLightThemeWithColors(
  primaryColor: kFastLightPurpleColor,
  primaryColorDark: kFastLightPurplePaletteColors.dark,
  secondaryColor: kFastLightIndigoColor,
  tertiaryColor: kFastLightTealColor,
);

final kLightTealFastTheme = FastThemeFactory.buildLightThemeWithColors(
  primaryColor: kFastLightTealColor,
  primaryColorDark: kFastLightTealPaletteColors.dark,
  secondaryColor: kFastLightPurpleColor,
  tertiaryColor: kFastLightBlueColor,
);

final kLightYellowFastTheme = FastThemeFactory.buildLightThemeWithColors(
  primaryColor: kFastLightYellowColor,
  primaryColorDark: kFastLightYellowPaletteColors.dark,
  secondaryColor: kFastLightIndigoColor,
  tertiaryColor: kFastLightTealColor,
);

final kLightOrangeFastTheme = FastThemeFactory.buildLightThemeWithColors(
  primaryColor: kFastLightOrangeColor,
  primaryColorDark: kFastLightOrangePaletteColors.dark,
  secondaryColor: kFastLightIndigoColor,
  tertiaryColor: kFastLightTealColor,
);
